8177015: STACK_SIZE_MINIMUM of 32k is not always enough for Mac OS X
authorcjplummer
Mon, 27 Mar 2017 11:54:04 -0700
changeset 46351 1b8f8edb7775
parent 46350 5fdb409ba877
child 46352 4ece6d1f3f76
8177015: STACK_SIZE_MINIMUM of 32k is not always enough for Mac OS X Summary: Bump up minimum to 64k. Reviewed-by: dholmes, dcubed
hotspot/test/runtime/Thread/TooSmallStackSize.java
--- a/hotspot/test/runtime/Thread/TooSmallStackSize.java	Mon Mar 27 19:05:54 2017 +0300
+++ b/hotspot/test/runtime/Thread/TooSmallStackSize.java	Mon Mar 27 11:54:04 2017 -0700
@@ -170,11 +170,11 @@
         checkStack("-XX:ThreadStackSize=", ThreadStackSizeString, "16");
 
         /*
          * Try with a 32k stack size, which is the size that the launcher will
          * set to if you try setting to anything smaller. This should produce the same
          * result as setting to 16k if the fix for 6762191 is in place.
          */
-        String min_stack_allowed = checkStack("-XX:ThreadStackSize=", ThreadStackSizeString, "32");
+        String min_stack_allowed = checkStack("-XX:ThreadStackSize=", ThreadStackSizeString, "64");
 
         /*
          * Try again with a the minimum stack size that was given in the error message
@@ -190,7 +190,7 @@
          * Now redo the same tests with the compiler thread stack size:
          */
         checkStack("-XX:CompilerThreadStackSize=", CompilerThreadStackSizeString, "16");
-        min_stack_allowed = checkStack("-XX:CompilerThreadStackSize=", CompilerThreadStackSizeString, "32");
+        min_stack_allowed = checkStack("-XX:CompilerThreadStackSize=", CompilerThreadStackSizeString, "64");
         checkMinStackAllowed("-XX:CompilerThreadStackSize=", CompilerThreadStackSizeString, min_stack_allowed);
         checkMinStackAllowed("-XX:CompilerThreadStackSize=", CompilerThreadStackSizeString, "513");
 
@@ -198,7 +198,7 @@
          * Now redo the same tests with the VM thread stack size:
          */
         checkStack("-XX:VMThreadStackSize=", VMThreadStackSizeString, "16");
-        min_stack_allowed = checkStack("-XX:VMThreadStackSize=", VMThreadStackSizeString, "32");
+        min_stack_allowed = checkStack("-XX:VMThreadStackSize=", VMThreadStackSizeString, "64");
         checkMinStackAllowed("-XX:VMThreadStackSize=", VMThreadStackSizeString, min_stack_allowed);
         checkMinStackAllowed("-XX:VMThreadStackSize=", VMThreadStackSizeString, "513");
     }
@@ -170,11 +170,11 @@
 
         /*
-         * Try with a 32k stack size, which is the size that the launcher will
+         * Try with a 64k stack size, which is the size that the launcher will
          * set to if you try setting to anything smaller. This should produce the same
          * result as setting to 16k if the fix for 6762191 is in place.